==> blender_2.66a.orig.tar.bz2: blender-2.66a/source/tools/check_style_c_config.py <==
import os

IGNORE = (

    # particles
    "source/blender/blenkernel/intern/boids.c",
    "source/blender/blenkernel/intern/cloth.c",
    "source/blender/blenkernel/intern/collision.c",
    "source/blender/blenkernel/intern/effect.c",
    "source/blender/blenkernel/intern/implicit.c",
    "source/blender/blenkernel/intern/particle.c",
    "source/blender/blenkernel/intern/particle_system.c",
    "source/blender/blenkernel/intern/pointcache.c",
    "source/blender/blenkernel/intern/sca.c",
    "source/blender/blenkernel/intern/softbody.c",
    "source/blender/blenkernel/intern/smoke.c",

    "source/blender/blenlib/intern/fnmatch.c",
    "source/blender/blenlib/intern/md5.c",
    "source/blender/blenlib/intern/voxel.c",

    "source/blender/blenloader/intern/readfile.c",
    "source/blender/blenloader/intern/versioning_250.c",
    "source/blender/blenloader/intern/versioning_legacy.c",
    "source/blender/blenloader/intern/writefile.c",

    "source/blender/editors/space_logic/logic_buttons.c",
    "source/blender/editors/space_logic/logic_window.c",
    
    "source/blender/imbuf/intern/dds/DirectDrawSurface.cpp",

    "source/blender/opencl/intern/clew.c",
    "source/blender/opencl/intern/clew.h",
    )

IGNORE_DIR = (
    "source/blender/collada",
    "source/blender/render",
    "source/blender/editors/physics",
    "source/blender/editors/space_logic",
    "source/blender/gpu",
    "source/blender/nodes",
    )


SOURCE_DIR = os.path.normpath(os.path.abspath(os.path.normpath(os.path.join(os.path.dirname(__file__), "..", ".."))))

==> blender_2.69.orig.tar.bz2: blender-2.69/source/tools/check_style_c_config.py <==
import os

IGNORE = (

    # particles
    "source/blender/blenkernel/intern/boids.c",
    "source/blender/blenkernel/intern/cloth.c",
    "source/blender/blenkernel/intern/collision.c",
    "source/blender/blenkernel/intern/effect.c",
    "source/blender/blenkernel/intern/implicit.c",
    "source/blender/blenkernel/intern/particle.c",
    "source/blender/blenkernel/intern/particle_system.c",
    "source/blender/blenkernel/intern/pointcache.c",
    "source/blender/blenkernel/intern/sca.c",
    "source/blender/blenkernel/intern/softbody.c",
    "source/blender/blenkernel/intern/smoke.c",

    "source/blender/blenlib/intern/fnmatch.c",
    "source/blender/blenlib/intern/md5.c",
    "source/blender/blenlib/intern/voxel.c",

    "source/blender/blenloader/intern/readfile.c",
    "source/blender/blenloader/intern/versioning_250.c",
    "source/blender/blenloader/intern/versioning_legacy.c",
    "source/blender/blenloader/intern/writefile.c",

    "source/blender/editors/space_logic/logic_buttons.c",
    "source/blender/editors/space_logic/logic_window.c",
    
    "source/blender/imbuf/intern/dds/DirectDrawSurface.cpp",

    "source/blender/opencl/intern/clew.c",
    "source/blender/opencl/intern/clew.h",
    )

IGNORE_DIR = (
    "source/blender/collada",
    "source/blender/render",
    "source/blender/editors/physics",
    "source/blender/editors/space_logic",
    "source/blender/freestyle",
    "source/blender/gpu",
    )


SOURCE_DIR = os.path.normpath(os.path.abspath(os.path.normpath(os.path.join(os.path.dirname(__file__), "..", ".."))))
